phpgroupware-cvs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Phpgroupware-cvs] property/setup tables_current.inc.php, 1.24 setup.inc


From: sigurdne
Subject: [Phpgroupware-cvs] property/setup tables_current.inc.php, 1.24 setup.inc.php, 1.12 tables_update.inc.php, 1.5
Date: Tue, 15 Mar 2005 09:47:00 +0100

Update of property/setup

Modified Files:
     Branch: MAIN
            tables_current.inc.php lines: +2 -2
            setup.inc.php lines: +2 -2
            tables_update.inc.php lines: +15 -2

Log Message:
no message

====================================================
Index: property/setup/tables_current.inc.php
diff -u property/setup/tables_current.inc.php:1.23 
property/setup/tables_current.inc.php:1.24
--- property/setup/tables_current.inc.php:1.23  Tue Mar  1 15:04:27 2005
+++ property/setup/tables_current.inc.php       Tue Mar 15 08:47:19 2005
@@ -797,7 +797,7 @@
                                'loc2' => array('type' => 'varchar','precision' 
=> '4','nullable' => True),
                                'loc3' => array('type' => 'varchar','precision' 
=> '4','nullable' => True),
                                'loc4' => array('type' => 'varchar','precision' 
=> '4','nullable' => True),
-                               'descr' => array('type' => 
'varchar','precision' => '50','nullable' => True),
+                               'descr' => array('type' => 'text','nullable' => 
True),
                                'category' => array('type' => 'int','precision' 
=> '4','nullable' => True),
                                'owner' => array('type' => 'int','precision' => 
'4','nullable' => True),
                                'access' => array('type' => 
'varchar','precision' => '7','nullable' => True),

====================================================
Index: property/setup/setup.inc.php
diff -u property/setup/setup.inc.php:1.11 property/setup/setup.inc.php:1.12
--- property/setup/setup.inc.php:1.11   Tue Mar  1 15:04:27 2005
+++ property/setup/setup.inc.php        Tue Mar 15 08:47:19 2005
@@ -24,7 +24,7 @@

        $setup_info['property']['name']      = 'property';
        $setup_info['property']['title']         = 'Property';
-       $setup_info['property']['version']   = '0.9.17.501';
+       $setup_info['property']['version']   = '0.9.17.502';
        $setup_info['property']['app_order'] = 8;
        $setup_info['property']['enable']    = 1;


====================================================
Index: property/setup/tables_update.inc.php
diff -u property/setup/tables_update.inc.php:1.4 
property/setup/tables_update.inc.php:1.5
--- property/setup/tables_update.inc.php:1.4    Tue Mar  1 15:04:27 2005
+++ property/setup/tables_update.inc.php        Tue Mar 15 08:47:19 2005
@@ -21,7 +21,7 @@
        */

        /**
        * Update property version from 0.9.15.001 to 0.9.15.002
        */

        $test[] = '0.9.17.500';
@@ -102,4 +102,17 @@
                $GLOBALS['setup_info']['property']['currentver'] = '0.9.17.501';
                return $GLOBALS['setup_info']['property']['currentver'];
        }
+
+       /**
+       * Update property version from 0.9.17.501 to 0.9.17.502
+       */
+
+       $test[] = '0.9.17.501';
+       function property_upgrade0_9_17_501()
+       {
+               
$GLOBALS['phpgw_setup']->oProc->AlterColumn('fm_request','descr',array('type' 
=> 'text','nullable' => True));
+               $GLOBALS['setup_info']['property']['currentver'] = '0.9.17.502';
+               return $GLOBALS['setup_info']['property']['currentver'];
+       }
+
 ?>
@@ -21,7 +21,7 @@

        /**
-       * Update property version from 0.9.15.001 to 0.9.15.002
+       * Update property version from 0.9.17.500 to 0.9.17.501
        */







reply via email to

[Prev in Thread] Current Thread [Next in Thread]